@@ -33,7 +33,7 @@
    Each vrank-geq1 plan reduces the vector rank by 1, picking out a
    dimension determined by the vecloop_dim field of the solver. */
 
-#include "rdft/rdft.h"
+#include "rdft.h"
 
 typedef struct {
      solver super;
